IDEFIX
######

Getting manga information.

.. image:: https://img.shields.io/pypi/v/idfx.svg
    :target: https://pypi.python.org/pypi/idfx

.. image:: https://img.shields.io/pypi/l/idfx.svg
    :target: https://pypi.python.org/pypi/idfx

.. image:: https://img.shields.io/pypi/dm/idfx.svg
    :target: https://pypi.python.org/pypi/idfx

